uniform_precip Package
======================

:mod:`uniform_precip` Package
-----------------------------

.. automodule:: landlab.components.uniform_precip
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`generate_uniform_precip` Module
-------------------------------------

.. automodule:: landlab.components.uniform_precip.generate_uniform_precip
    :members:
    :undoc-members:
    :show-inheritance:

